/*
 * DynamicGraphReader.cpp
 *
 *  Created on: 01.06.2013
 *      Author: cls
 */

#include <networkit/io/DynamicGraphReader.hpp>

namespace NetworKit {


} /* namespace NetworKit */
